@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUTCAsFetcher
 
 
@@ -66,7 +67,7 @@ class NUContainerInterface(NURESTObject):
     """ Represents a ContainerInterface in the VSD
 
         Notes:
-            Read only API that can retrieve the container interface associated with a domain, zone or subnet for mediation created container's for REST created  container interfaces you need to set the additional proxy header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example :bob@Alcatel Lucent), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
+            API that can retrieve the container interface associated with a domain, zone or subnet for mediation created container's for REST created  container interfaces you need to set the additional proxy header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example :bob@Alcatel Lucent), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
     """
 
     __rest_name__ = "containerinterface"
@@ -106,6 +107,8 @@ class NUContainerInterface(NURESTObject):
         self._ip_address = None
         self._vport_id = None
         self._vport_name = None
+        self._ipv6_address = None
+        self._ipv6_gateway = None
         self._name = None
         self._last_updated_by = None
         self._gateway = None
@@ -121,7 +124,6 @@ class NUContainerInterface(NURESTObject):
         self._zone_id = None
         self._zone_name = None
         self._container_uuid = None
-        self._associated_floating_ip_address = None
         self._attached_network_id = None
         self._attached_network_type = None
         self._multi_nic_vport_name = None
@@ -131,6 +133,8 @@ class NUContainerInterface(NURESTObject):
         self.expose_attribute(local_name="ip_address", remote_name="IPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_id", remote_name="VPortID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_name", remote_name="VPortName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
@@ -146,7 +150,6 @@ class NUContainerInterface(NURESTObject):
         self.expose_attribute(local_name="zone_id", remote_name="zoneID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_name", remote_name="zoneName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="container_uuid", remote_name="containerUUID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="associated_floating_ip_address", remote_name="associatedFloatingIPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_id", remote_name="attachedNetworkID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_type", remote_name="attachedNetworkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L2DOMAIN', u'SUBNET'])
         self.expose_attribute(local_name="multi_nic_vport_name", remote_name="multiNICVPortName", attribute_type=str, is_required=False, is_unique=False)
@@ -301,6 +304,60 @@ class NUContainerInterface(NURESTObject):
         self._vport_name = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
+    @property
+    def ipv6_gateway(self):
+        """ Get ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the Container is connected to"
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        return self._ipv6_gateway
+
+    @ipv6_gateway.setter
+    def ipv6_gateway(self, value):
+        """ Set ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the Container is connected to"
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        self._ipv6_gateway = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -694,33 +751,6 @@ class NUContainerInterface(NURESTObject):
         self._container_uuid = value
 
     
-    @property
-    def associated_floating_ip_address(self):
-        """ Get associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        return self._associated_floating_ip_address
-
-    @associated_floating_ip_address.setter
-    def associated_floating_ip_address(self, value):
-        """ Set associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        self._associated_floating_ip_address = value
-
-    
     @property
     def attached_network_id(self):
         """ Get attached_network_id value.
