@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -42,7 +43,7 @@ class NUNetworkMacroGroup(NURESTObject):
     """ Represents a NetworkMacroGroup in the VSD
 
         Notes:
-            Administrators of an enterprise can define macros that are set of IP addresses that identify enterprise networks. These macros can be used in the ACL definitions by network designers and other users to identify access restrictions towards specific enterprise networks.
+            Network Macro Groups are a collection of existing Network Macros. These groups can be used in Security Policies in order to create rules that matches multiple Network Macros.
     """
 
     __rest_name__ = "networkmacrogroup"
@@ -77,15 +78,15 @@ class NUNetworkMacroGroup(NURESTObject):
         self._name = None
         self._last_updated_by = None
         self._description = None
-        self._network_macros = None
         self._entity_scope = None
+        self._is_saa_s_type = None
         self._external_id = None
         
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="network_macros", remote_name="networkMacros", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="is_saa_s_type", remote_name="isSaaSType", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -98,7 +99,7 @@ class NUNetworkMacroGroup(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.enterprise_networks = NUEnterpriseNetworksFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.enterprise_networks = NUEnterpriseNetworksFetcher.fetcher_with_object(parent_object=self, relationship="member")
         
 
         self._compute_args(**kwargs)
@@ -178,33 +179,6 @@ class NUNetworkMacroGroup(NURESTObject):
         self._description = value
 
     
-    @property
-    def network_macros(self):
-        """ Get network_macros value.
-
-            Notes:
-                None
-
-                
-                This attribute is named `networkMacros` in VSD API.
-                
-        """
-        return self._network_macros
-
-    @network_macros.setter
-    def network_macros(self, value):
-        """ Set network_macros value.
-
-            Notes:
-                None
-
-                
-                This attribute is named `networkMacros` in VSD API.
-                
-        """
-        self._network_macros = value
-
-    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -232,6 +206,33 @@ class NUNetworkMacroGroup(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def is_saa_s_type(self):
+        """ Get is_saa_s_type value.
+
+            Notes:
+                Determines whether this entity is specific to SaaS Breakout Feature.
+
+                
+                This attribute is named `isSaaSType` in VSD API.
+                
+        """
+        return self._is_saa_s_type
+
+    @is_saa_s_type.setter
+    def is_saa_s_type(self, value):
+        """ Set is_saa_s_type value.
+
+            Notes:
+                Determines whether this entity is specific to SaaS Breakout Feature.
+
+                
+                This attribute is named `isSaaSType` in VSD API.
+                
+        """
+        self._is_saa_s_type = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
