@@ -73,6 +73,12 @@ from .fetchers import NUGatewayTemplatesFetcher
 from .fetchers import NUPATNATPoolsFetcher
 
 
+from .fetchers import NUScheduledTestSuitesFetcher
+
+
+from .fetchers import NUICMPEchoTestDefinitionsFetcher
+
+
 from .fetchers import NULDAPConfigurationsFetcher
 
 
@@ -268,6 +274,9 @@ from .fetchers import NUNSGGroupsFetcher
 from .fetchers import NUNSRedundantGatewayGroupsFetcher
 
 
+from .fetchers import NUEthernetSegmentGWGroupsFetcher
+
+
 from .fetchers import NUPublicNetworkMacrosFetcher
 
 
@@ -518,6 +527,12 @@ class NUEnterprise(NURESTObject):
         self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.scheduled_test_suites = NUScheduledTestSuitesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
+        self.icmp_echo_test_definitions = NUICMPEchoTestDefinitionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.ldap_configurations = NULDAPConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -713,6 +728,9 @@ class NUEnterprise(NURESTObject):
         self.ns_redundant_gateway_groups = NUNSRedundantGatewayGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.ethernet_segment_gw_groups = NUEthernetSegmentGWGroupsFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.public_network_macros = NUPublicNetworkMacrosFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
